<?php
namespace Plugin\Controller;

use Plugin\Exception\Error;
use Plugin\Server\Response;
class Controller {
	
	private $route;
	
	public static function initialize($route = null){
		$controller = new self();
		$controller->setRoute($route);
		return $controller;
	}
	
	public function setRoute($route){
		$this->route = $route;
		
	}
	
	/**
	 * Render the page. 
	 * This method calls the controller form the route and makes sure the render is an
	 * instance of response
	 * @return \Plugin\Server\Response
	 */
	public function render(){
		
		$route = $this->route;
		list($app,$package,$control,$method) = explode(":", $route["config"]);
		
		if (!$app || !$package || !$control || !$method){
			Error::throw500("The render failed. Check your Route files:\n".print_r($this->route,true));
		}
		$appController = $this->buildController($app, $package, $control);
		$appControllerName = get_class($appController);
		$methodName = "{$method}Action";
		
		if (!method_exists($appController, $methodName)){
			Error::throw500("Render failed. The method '$methodName' is not defined in $appControllerName");
		}
		
		$response = call_user_func_array(array($appController,$methodName), $route["values"]);
		
		if (!($response instanceof Response)){
			Error::throw500("The return value from {$appControllerName} is not of type Response. You probably forgot to return a response.");
		}
		
		return $response;
	}
	private function buildController($app,$package,$control){
		$className = "src\\$app\\$package\\Controller\\{$control}Controller";
		//echo $className;exit;
		if (!class_exists($className)){
			Error::throw500("The controller '$className' does not exist");
		}
		
		return new $className();
	}
	
	public function isHeadRequest(){
		return $_SERVER["REQUEST_METHOD"] === "HEAD";
	}
}