<?php
namespace src\Blog\Model\Interaction;

use Plugin\DBMS\Interaction;
use Plugin\Server\Request;

class ArticleDataManager extends Interaction{
	
	public function getLatestArticles($total = 10){
		// Return 10 latest articles
		
		$sql = "SELECT * FROM article
				ORDER BY date_published DESC
				LIMIT %d";
		$sql = sprintf($sql,(int)$total);
		
		return $this->simplyQuery($sql); ;
	}
	
	public function getArticleByTitle($title){
		$sql = "SELECT * FROM article 
				WHERE url = '%s' 
				LIMIT 1";
		$sql = sprintf($sql,
				$this->escape($title));
		$results = $this->simplyQuery($sql);
		
		return isset($results[0])?$results[0]:false;
	}
	
	public function getAllArticlesList($limit = 25){
		$sql = "SELECT article_id,title,date_published FROM article
				ORDER BY date_added DESC";
		return $this->simplyQuery($sql);
	}
	
	public function getById($id){
		$sql = "SELECT * FROM article
				WHERE article_id = %d";
		$sql = sprintf($sql,(int) $id);
		$result = $this->simplyQuery($sql);
		return $result && isset($result[0])? $result[0]:false;
	}
	
	/**
	 * 
	 * @param string $id
	 * @param Request $req
	 * @return string status "success|failed"
	 */
	public function saveEdit($id,$req){
		$em = $this->getManager();
		$sql = "UPDATE article SET 
				`title` = '%s',
				`url` = '%s',
				`content` = '%s'
				WHERE article_id = %d;";
		$isError = false;
		$title = $this->escape(trim($req->getParam("title")));
		$url = $this->escape(trim($req->getParam("url")));
		$content = $this->escape(trim($req->getParam("content")));
		$id = (int) $id;
		
		if (strlen($title) < 3){
			$isError = true;
		}
		if (strlen($url) < 3){
			$isError = true;
		}
		if (strlen($content) < 100){
			$isError = true;
		}
		
		if ($isError) {
			return "failed";
		}
		$sql = sprintf($sql,$title,$url,$content, $id );
		
		$result = $em->execSQL($sql);
		
		return $result? "success":"failed";
	}
	
	/**
	 * 
	 * @param Request $req
	 * @return string
	 */
	public function saveArticle($req){
		$em = $this->getManager();
		$sql = "INSERT INTO article (title,url,content,date_added,date_published)
				VALUES ('%s','%s','%s','%s','%s');";
		$isError = false;
		$title = $this->escape(trim($req->getParam("title")));
		$url = $this->escape(trim($req->getParam("url")));
		$content = $this->escape(trim($req->getParam("content")));
		$date_added = date("Y-m-d H:i:s");
		$date_published = $this->escape(trim($req->getParam("publish_date")));
	
		if (strlen($title) < 3){
			$isError = true;
		}
		if (strlen($url) < 3){
			$isError = true;
		}
		if (strlen($content) < 100){
			$isError = true;
		}
		
		if (strlen($date_published) < 3){
			// validate the date
			$isError = true;
		}
	
		if ($isError) {
			return 0;
		}
		$sql = sprintf($sql,$title,$url,$content, $date_added,$date_published);
	
		
		$result = $em->execSQL($sql);
		return $result;
	}
}